from collections import Counter


class work_dy(object):

    def __init__(self, *world):
        self.world = world[0]
        if len(world) > 1:
            self.world2 = world[1]

    def merge(self):  # Объединяем два словаря
        dic3 = self.world2.copy()
        dic3.update(self.world)
        return dic3

    def chunk(self):  # Разбиение на фрагменты
        return [self.world[i:i + int(self.world2)] for i in range(0, len(self.world), int(self.world2))]

    def get_vowels(self):  # Получаем гласные
        return [each for each in self.world if each in "aeiou"]

    def capitalize(self):  # Первая буква в верхнем регистре
        return self.world.title()

    def check_duplicate(self):  # Проверка дубликатов
        return len(self.world) != len(set(self.world))

    def Filtering(self):  # Фильтрация значений
        return list(filter(None, self.world))

    def ByteSize(self):  # Размер в байтах
        return len(self.world.encode("utf8"))

    def anagrams(self):  # Анаграммы
        return Counter(self.world) == Counter(self.world2)

    def palindrome(self):  # Проверка палиндромов
        return self.world == self.world[::-1]




from setuptools import setup

setup(name='anshils',
      version='0.1.7',
      description='pip install anshils',
      packages=['anshils'],
      author_email='i89041056398@gmail.com',
      zip_safe=False)



from .Gaussiandistribution import work_dy


def helps():  # поддержка
    print('work_dy(string).get_vowels()   # Получаем гласные')
    print('Этот пример возвращает в строке найденные гласные "a e i o u".'
          ' Это может оказаться полезным при поиске или обнаружении гласных.')
    print('work_dy(string).capitalize() - Первая буква в верхнем регистре')
    print()
    print('Этот пример используется для превращения каждой первой буквы символов строки в прописную букву. '
          'Он работает со строкой из одного или нескольких символов и будет полезен при анализе текста или записи данных в файл и т.п.')
    print('work_dy(list).check_duplicate() - Проверка дубликатов ')
    print('Это самый быстрый способ проверки наличия повторяющихся значений в списке.')
    print('work_dy(list).Filtering() - Фильтрация значений ')
    print('Этот пример используется для устранения всех ложных значений из списка, например false, 0, None, " "')
    print('work_dy(string).ByteSize() - Размер в байтах ')
    print('Этот пример возвращает длину строки в байтах, что удобно, когда вам нужно знать размер строковой переменной.')
    print('work_dy(string1, string2).anagrams() - Анаграммы ')
    print('Этот код полезен для проверки того, является ли строка анаграммой. Анаграмма — это слово, полученное перестановкой букв другого слова.')
    print('work_dy(data).palindrome() - Проверка палиндромов ')
    print('Неэффективный, как быстро проверить наличие палиндромов.')
    print('work_dy(list, int).chunk() - Разбиение на фрагменты ')
    print('Этот пример поможет, разбить список на фрагменты и разделить его на меньшие части.')
    print('work_dy(dict1, dict2).merge() - Объединяем два словаря ')
    print('Этот пример выполняет слияние двух словарей в один.')


